/*
	File: RC5.r
	Contains: Philips RC-5 command codes for Newton Remote Control
	
	Copyright  1993 by Apple Computer, Inc.  All rights reerved.
	Written by $mike cremer.
	
	Rez -c RSED -t rsrc RC5.r -o RC5.rsrc
*/

/*
	RC-5 is a 14-bit Manchester-encoded command word.
	The 14-bit word is broken into several fields:
	
		S F C x x x x x y y y y y y
		
	S: start bit (1)
	F: function bit (0/1)
	C: control bit (0/1)
	x: device id field (0-31)
	y: command field (0-64)
	
	The start bit marks the start of a command.
	
	The function bit selects one of two command sets,
	effectively yielding a command in the range 0-127.
	The F must be set for commands (0-63) and cleared
	for commands (64-127).
	
	The control bit is used to distinguish between
	multiple sends of a single command, and multiple
	distinct commands.  This bit should be toggled
	for each distinct command sent.
	
	The device ID and command fields are unsigned numbers.
	
	Example:
	The PowerCD is device 14.  The code for "play"
	is 53.  The "play" command is therefore:
	
	1 1 0 0 1 1 1 0 1 1 0 1 0 1
	S F C ----14--- -----53----
	
	The bits are Machester encoded with a cell-time of
	1778 s, meaning that each bit has a half-cell time
	of ~850 s.
	
	A "1" bit is sent as a low-to-high transition at mid-cell.
	A "0" bit is sent as a high-to-low transition at mid-cell.
	
	The waveform for the "play" command looks like this:

    . 1 . 1 . 0 . 0 . 1 . 1 . 1 . 0 . 1 . 1 . 0 . 1 . 0 . 1 .
      +-+ +---+ +-+   +-+ +-+ +---+   +-+ +---+   +---+   +-+
	  | | |   | | |   | | | | |   |   | | |   |   |   |   | |
	--+ +-+   +-+ +---+ +-+ +-+   +---+ +-+   +---+   +---+ +---
	   1 1  2  1 1  2  1 1 1 1  2   2  1 1  2   2   2   2  1

	The top numbers are the bit format of the command; '.' marks
	each bit boundary.  The bottom numbers are bit times which will
	produce the Machester-encoded waveform.
*/

#include "RemoteTypes.r"

resource 'IRCD' (128, "RC5Play0") {
	'ply0',
	850,		// timeBase, in microseconds
	1,			// leadIn, in timeBase units
	32,			// repeat, in timeBase units
	128,		// leadOut, in timeBase units
	{
		1, 2, 1,
		1, 2, 1, 1,
		1, 1, 2, 2,
		1, 1, 2, 2,
		2, 2, 1
	}
};

resource 'IRCD' (129, "RC5Play1") {
	'ply1',
	850,
	1,
	32,
	128,
	{
		1, 1, 1,
		2, 2, 1, 1,
		1, 1, 2, 2,
		1, 1, 2, 2,
		2, 2, 1
	}
};

resource 'IRCD' (130, "RC5Stop0") {
	'stp0',
	850,
	1,
	32,
	128,
	{
		1, 2, 1,
		1, 2, 1, 1,
		1, 1, 2, 2,
		1, 1, 2, 2,
		1, 1, 2
	}
};

resource 'IRCD' (131, "RC5Stop1") {
	'stp1',
	850,
	1,
	32,
	128,
	{
		1, 1, 1,
		2, 2, 1, 1,
		1, 1, 2, 2,
		1, 1, 2, 2,
		1, 1, 2
	}
};

resource 'IRCD' (132, "RC5Pause0") {
	'pse0',
	850,
	1,
	32,
	128,
	{
		1, 2, 1,
		1, 2, 1, 1,
		1, 1, 2, 2,
		1, 1, 2, 1,
		1, 1, 1, 1,
		1
	}
};

resource 'IRCD' (133, "RC5Pause1") {
	'pse1',
	850,
	1,
	32,
	128,
	{
		1, 1, 1,
		2, 2, 1, 1,
		1, 1, 2, 2,
		1, 1, 2, 1,
		1, 1, 1, 1,
		1
	}
};

resource 'IRCD' (134, "RC5Next0") {
	'nxt0',
	850,
	1,
	32,
	128,
	{
		1, 2, 1,
		1, 2, 1, 1,
		1, 1, 2, 2,
		2, 1, 1, 1,
		1, 1, 1, 1,
		1
	}
};

resource 'IRCD' (135, "RC5Next1") {
	'nxt1',
	850,
	1,
	32,
	128,
	{
		1, 1, 1,
		2, 2, 1, 1,
		1, 1, 2, 2,
		2, 1, 1, 1,
		1, 1, 1, 1,
		1
	}
};

resource 'IRCD' (136, "RC5Prev0") {
	'prv0',
	850,
	1,
	32,
	128,
	{
		1, 2, 1,
		1, 2, 1, 1,
		1, 1, 2, 2,
		2, 1, 1, 1,
		1, 1, 1, 2,
		1
	}
};

resource 'IRCD' (137, "RC5Prev1") {
	'prv1',
	850,
	1,
	32,
	128,
	{
		1, 1, 1,
		2, 2, 1, 1,
		1, 1, 2, 2,
		2, 1, 1, 1,
		1, 1, 1, 2,
		1
	}
};

resource 'IRCD' (138, "RC5FF0") {
	'ff0 ',
	850,
	1,
	32,
	128,
	{
		1, 2, 1,
		1, 2, 1, 1,
		1, 1, 2, 1,
		1, 2, 1, 1,
		1, 1, 1, 1,
		2
	}
};

resource 'IRCD' (139, "RC5FF1") {
	'ff1 ',
	850,
	1,
	32,
	128,
	{
		1, 1, 1,
		2, 2, 1, 1,
		1, 1, 2, 1,
		1, 2, 1, 1,
		1, 1, 1, 1,
		2
	}
};

resource 'IRCD' (140, "RC5Rew0") {
	'rew0',
	850,
	1,
	32,
	128,
	{
		1, 2, 1,
		1, 2, 1, 1,
		1, 1, 2, 1,
		1, 2, 1, 1,
		1, 1, 1, 1,
		1, 1, 1
	}
};

resource 'IRCD' (141, "RC5Rew1") {
	'rew1',
	850,
	1,
	32,
	128,
	{
		1, 1, 1,
		2, 2, 1, 1,
		1, 1, 2, 1,
		1, 2, 1, 1,
		1, 1, 1, 1,
		1, 1, 1
	}
};

